@@ -1,5 +1,4 @@
-package # Hide from pause
-   TestApp::View::Wx;
+package TestApp::View::Wx;
 
 use strict;
 use base 'Catalyst::View::Wx';
